espconfig(1)

espconfig is a utility provided for the configuration ESP from the command line. This utility bypasses the webserver and directly interacts with the ESP database.

As shipped in IRIX 6.5.15. Added in IRIX 6.5.15.

NAME
     espconfig is a utility provided for the configuration ESP from the
     command line.  This utility bypasses the webserver and directly interacts
     with the ESP database.

INFORMATION COMMANDS
SYNOPSIS
     espconfig -help [<prototype>]
     espconfig -spec
     espconfig -version

DESCRIPTION
     The espconfig -help prints the list of command specifications. The
     optional <prototype> parameter is used to list commands that <prototype>
     matches some substring in the specification text.  For example,
     'espconfig -help add' will list all commands containing character
     sequence 'add' in the specification.

     The espconfig -spec command prints all commands specification in the way
     the command line is parsed to match the specification.

     The espconfig -version command gives the version of espconfig application
     with the date of the build.

     espconfig will format tabular output to fit to screen width. If the width
     can't be obtained, it is assumed to be 80 columns wide.

EVENT CONFIGURATION
SYNOPSIS
     espconfig -show evtype {-tid <type id>
                            |-td <type description>
                            |-cid <class id>
                            |-cd <class description>}
                            [-enable|-disable]
                            [-log|-nolog]
                            [-sgmclient <client alias>]
     espconfig -list evtype [-cid <class id>
                            |-cd <class description>]
                            [-enable|-disable]
                            [-log|-nolog]
                            [-sgmclient <client alias>]
     espconfig -add evtype -td <type description>
               {-cid <class id> | -cd <class description>}
               [-throttle <throttle value>]
               [-enable|-disable]
               [-acfreq <action frequency value>]
               [-acid <action id>
               |-acd  <action description>]
     espconfig -update evtype -tid <type id>
               [-sgmclient <client alias>]
               [-td <type description>]
               [-throttle <throttle value>]
               [-enable|-disable]
               [-log|-nolog]
               [-acfreq <action frequency value>]
               [-acid <action id>
               |-acd  <action description>]
               [-noacid <action id>
               |-noacd  <action description>]
     espconfig -delete evtype {-tid <type id>
                              |-td <type description>}
     espconfig -update evclass -cid <class id>
                               -cd <class description>
     espconfig -delete evclass {-cid <class id>
                               |-cd <class description>}
     espconfig -list evclass
     espconfig -delete events
               [-sysid <system id>|-host <host name>]

DESCRIPTION
     The -show evtype command is used to show all fields of the selected event
     type. The key -tid specifies event type by type id. The key -td specifies
     event type by type description. Only one of these keys need to be
     specified at a time. In the case the type description is not unique, all
     matched event types are printed unless -enable or -disable is selected.
     Also, selection criteria can be based on the class they belong to using
     -cid, -cd, -log or -nolog  keys.

     The -list evtype command is used to list event type ids with event
     descriptions. Option -cid specifies list by class id. Option -cd
     specifies list by class description. Only one of these options need to be
     specified at a time. If both options are missing, all event types are
     listed unless a combination of -enable or -disable or -log or -nolog is
     selected.

     The -add evtype command is used to add new events to ESP. The new event
     has to be specified by the key -td with the event type description.  The
     type description has to be unique in the event class. The Event class has
     to be specified by the key -cid with class id or by the key -cd with the
     class description. The class id always defines the existing class, while
     class description can specify an existing class or the new class. -log
     select Automatic Call logging ( by default ). -nolog turn that off. ESP
     will assigned a new event type ID and display its value when the command
     is completed.

     The -update evtype command is used to update fields in an existing event
     type. The event type must be specified by type id with the -tid key.  -
     log select Automatic Call logging ( by default ). -nolog turn that off.

     The -sgmclient option specifies the client alias for requested client
     information when running on SGM site.

     The following options specifies fields value for new event in -add evtype
     command or updated value for -update evtype command. If some options are
     missing default values are used in -add evtype command. In -update evtype
     parameters not provided are left unchanged. The options are:

     -td <type description>
             option allows to change type description in -update evtype
             command. Only custom created event types can be updated with this
             option.

     -throttle <throttle value>
             option is used to set or update the throttle value, representing
             the number of event occurrences prior to registration into the
             ESP database. The default value is 1.

     -enable | -disable
             options define whether the event is enabled or disabled in new or
             updated event type. Only one of the these options can be
             specified at a time. The default value is disabled.

     -acid <action id>

     -acd  <action description>
             options are used to associate an action with the created event
             type or add another action associated with the updated event
             type. Only one of the these options can be specified at a time.
             If both options are missing no actions are associated with the
             new event type and actions associated with event type are left
             unchanged. The key -acid defines the new action by action id,
             while -acd the key defines the new action by action description.

     -noacid <action id>

     -noacd  <action description>
             options are used to remove an action from updated event type.
             Only one of the these options can be specified at a time. If both
             options are missing actions associated with updated event type
             are left unchanged. The key -acid defines dropped action by the
             action id, while -acd key defines it by the action description.

     The -delete evtype command is used to delete events. Only custom defined
     events can be deleted. The event to be deleted must be uniquely specified
     by the type id or the type description with options -tid or -td. Only one
     key can be specified at a time. The type id is unique for events,
     however, the description can be the same across different event classes.
     If type description is not unique, then a table of all event types
     matching the given are listed along with their type id's. The user can
     then use the -tid for appropriate type for deletion. If the type being
     deleted is the last in its class, then the class is also removed.

     The -update evclass command can be used to update class description for
     custom defined event classes. -cid key is specifies the selected event
     class by its id.  -cd key is specifies the new class description for this
     class.

     The -delete evclass command can be used to delete the custom defined
     event classes. Classes for deletion can be specified by the class id with
     -cid key, or by class description with -cd key. Only one of keys can be
     specified in the command line.

     The -list evclass command is used to list event classes. The command
     lists the event class ID and event class description.

     The -delete events command is used to delete all events related
     structures:  types, classes, actions and cross references. If espconfig
     is running on an SGM, the optional key -sysid defines the affected client
     by specifying the system id. The optional -host key specifies the client
     system by the host name. Only one of the keys can be specified on command
     line. If both keys are missing, the current system is affected. The event
     structure for the client is removed from SGM. The client itself is not
     affected.

EXAMPLES
      1. espconfig -add  evtype
                   -td "XXX diagnostic memory overflow"
                         -cd "XXX diagnostic"
      2. espconfig -add  evtype -td "XXX failure 0102"
                                -cd "XXX diagnostic"
      3. espconfig -list evtype -cd "XXX diagnostic"

         TypeId   Type description
         ------   ----------------
         8400000  "XXX diagnostic memory overflow"
         8400001  "XXX failure 0102"

      4. espconfig -update evtype -tid 8400001
                   -td "XXX diagnostic: data parity"
                      -acd "Mail administrator"
      5. espconfig -update evtype -tid 8400001
                   -enable -throttle 5
                      -noacd "Mail administrator"
                      -acd "Page owner"
      6. espconfig -update evtype -tid 8400001
                   -acd "Mail owner"

     Example 1 creates a new event type. Example 2 creates another event type
     into the existing class. Example 3 gives the list of created events with
     type ids. Example 4 updates the type description for the second event
     type and associates an action to it. Example 5 removes an action and
     associates another action to the event. It also updates throttle value
     and enables the event type. Example 6 adds one more action to the same
     event type.
     Command lines are wrapped here only for representation purpose.

EVENT ACTION CONFIGURATION
SYNOPSIS
     espconfig -show evaction {-acid <action id>
                               |-acd <action description>}
     espconfig -list evaction
     espconfig -add evaction  -acd <action description>
                              -act <action string>
                            [-user <name>]
                            [-retry <count>]
                            [-tout <timeout value>]
                            [-throttle <throttle value>]
                            [-enable|-disable]
     espconfig -update evaction
                            {-acid <action id>
                                   [-acd <new action description>] |
                             -acd <action description>}
                            [-act <action string>]
                            [-user <name>]
                            [-retry <count>]
                            [-tout <timeout value>]
                            [-throttle <throttle value>]
                            [-enable|-disable]

DESCRIPTION
     The -show evaction command is used to show all fields of the selected
     event action. The key -acid specifies the event action by action id. The
     key -acd specifies the event action by the action description. Only one
     of these keys can be specified at a time.

     The -list evaction command is used to list event actions. The action ids
     and action descriptions are listed.

     The -add evaction command is used to create new actions. Adding an action
     requires the action description and action string as mandatory
     parameters. The action description is specified by the -acd key, while
     the action string is specified by the -act key.

     The -update evaction command can be used to update parameters that apply
     to an existing action. The action to be updated can be selected by the
     action id with the -acid key followed by a valid action id. In this case
     the optional -acd key specifies the updated action description. If -acid
     key is missing, then -acd key is mandatory to specify the updated action
     by action description.

     The following options specifies field values for a new action in -add
     evaction command or updated value for -update evaction command. If some
     options are missing, default values are used in -add evaction command. In
     the -update evaction command missed fields are left unchanged. The
     options are:

     -act <action string>
             option allows to change the action string in -update evaction
             command. In -add evaction command this key is mandatory.

     -user <name>
             option defines the UNIX user name for new or updated action. The
             user permissions are used to execute the action string. The
             default user is 'nobody'.

     -retry <count>
             option defines the retry count to retry the action for new or
             updated event action, if the action is not executed successfully.
             The default value is 0.

     -tout <timeout value>
             option defines the timeout value within which the action being
             executed is to be completed. If this timeout period is completed
             and the action is still running, the action will be killed. The
             default value is 0.

     -throttle <throttle value>
             option defines the throttling value for the action. The throttle
             for the action defines the number of occurrences of event before
             action is taken. The default value is 1.

     -enable | -disable
             options define if the new or updated action is enabled or
             disabled. Only one of the two options can be specified with the
             command.

IMPORTING AND EXPORTING EVENTS
SYNOPSIS
     espconfig -load  eventprofile <eventprofile name>
     espconfig -add   eventprofile <eventprofile name>
     espconfig -merge eventprofile <eventprofile name>
     espconfig -drop  eventprofile <eventprofile name>
     espconfig -save  eventprofile <eventprofile name>
     espconfig -list  eventprofile [<eventprofile name>]

DESCRIPTION
     In general, ESP eventprofile filename are all located in
     /var/esp/eventprofiles directory.  If an extension of ".esp" is not
     supplied, espconfig will append it. If a profile name is supplied using
     an absolute path, the directory location will be removed and the above-
     mentioned default will be prepended instead.

     The -load command clears the database and re-installs the new set of
     events and actions (if defined) from the file eventprofile name.

     The -add command compares events in the ESP database and inserts only new
     events that are being introduced from the file eventprofile name.

     The -merge command compares events in the ESP database for event
     parameters and updates ones that are different as in the file
     eventprofile name. If the event does not exist in the existing list of
     events in the ESP database, then the event is added to the database with
     the new set of parameters as defined for the event.

     The -drop command drops all events from the ESP database as defined by
     the file eventprofile name.  However, each profile that is loaded in the
     database is first checked to determine if the event being dropped is part
     of any other profile. If so, the event is not dropped

     The -save command behaves differently if the ESP profile filename already
     exist or not. (1) If it does not exist, it saves the entire set of events
     and associated actions to the file eventprofile name ;  (2) If it already
     exist, the profile is saved again using the list of events in the
     eventprofile name but using the data present in ESP database.

     The -list command list current ESP profiles and their load status.  If
     Loaded shows as 0, it means the profile has been de-activated.

EXPORTING AND IMPORTING ESP ENVIRONMENT
SYNOPSIS
     espconfig -save espenv
                            [global] [ipaddr] [user]
                            [site|customer_profile] [all] [-to <file name> ]
     espconfig -load espenv
                            [global] [ipaddr] [user]
                            [site|customer_profile] [all] -from <file name>

DESCRIPTION
     The -save command saves optional ESP environment data as specified into
     the file file name. The [all] option saves all the four states (global
     configuration - global, user configuration - user, site information -
     site and IP address information - ipaddr) from ESP to the file file name.
     If the -to option is not provided, the content data is displayed on the
     standard output.

     The -load command is used to load the specified set of configuration from
     the file file name. If the [all] option is used, all the four states
     (global configuration - global, user configuration - user, site
     information - site and IP address information - ipaddr) are loaded as the
     new ESP environment.

IP ADDRESSES CONFIGURATION
SYNOPSIS
     espconfig -enable  ipaddr <ip address>...<ip address>
     espconfig -disable ipaddr <ip address>...<ip address>
     espconfig -delete  ipaddr <ip address>...<ip address>
     espconfig -list    ipaddr <ip address>...<ip address>
                            [-enabled | -disabled]

DESCRIPTION
     The -enable command is used to enable access for given IP addresses list.
     If IP address from given list is already enabled, then its status remains
     unchanged. Disabled IP addresses are enabled. If the IP address is not
     already in the available list, then the IP addresses are added to the ESP
     database in an enabled state. At least one <ip address> must be provided.

     The -disable command is used to disable access for given IP addresses
     list.  If IP address from given list was disabled before its status is
     unchanged. Enabled IP addresses are disabled. Non-existent IP addresses
     are added to the ESP database in a disabled state. At least one <ip
     address> must be provided.

     The -delete command is used to delete given IP addresses from the system.
     At least one <ip address> must be provided.

     The -list command is used to list IP addresses available in the system
     with its state. If the ip address list is not provided, all entries are
     listed. Providing the -enabled or the -disabled option lists only
     addresses that are either enabled or disabled.

USERS AND USER PERMISSIONS CONFIGURATION
SYNOPSIS
     espconfig -add    user -name <user name> [-p <password>]
     espconfig -delete user -name <user name> [-p <password>]
     espconfig -update user -name <user name> [-p <password>]
     espconfig -list   user [-name <user name>]
     espconfig -createadmin
     espconfig -add    permdesc -perm <permission name>
                                -desc <permission description>
     espconfig -delete permdesc -perm <permission name>
     espconfig -list   permdesc
               [-perm <permission name>..<permission name>]
     espconfig -add    userperm [-name <user name>]
                                 -perm <permission name>
     espconfig -delete userperm [-name <user name>]
                                [-perm <permission name>]
     espconfig -list   userperm [-name <user name>]
                                [-perm <permission name>]

DESCRIPTION
     The -add user command is used to add new user to the system. The key
     -name specifies new user name. The key -p specifies user password. If the
     password key is missing, the command will prompt for an non-echoed
     verified input for the password.

     The -delete user command is used to delete the user from the system. The
     key -name specifies user name. The key -p specifies user password.  If
     password key is not provided, the command will prompt for a password in
     an non-echoed mode.

     The -update user command is used to update the user password. The key
     -name specifies user name.  The  key -p specifies new user password. If
     the key -p is missing, then the command will prompt for password in an
     non-echoed mode.

     The -list user command is used to list the user(s). The key -name
     specifies the user name. If key -name is missing, all users are listed.

     The -createadmin command is used to create the default user
     (administrator/partner) with all permissions.

     The -add permdesc command is used to add new kind of permission into the
     system. The key -perm defines the permission name and key -desc defines
     permission description.

     The -delete permdesc command is used to delete a permission from the
     system. The key -perm defines permission name.

     The -list permdesc command lists the permissions available in ESP. The
     key -perm defines the permission name. If the key -perm is not provided,
     all permission descriptions are listed.

     The -add userperm command is used to add permissions to a user. The key
     -perm defines the permission name. The key -name defines the user name.
     If -name key is missing, then the permission is added to all the users.

     The -delete userperm command is used to remove permission from the user.
     The key -name defines the user name. If -name key is missing, then the
     specified permission is removed from all users. The key -perm defines the
     permission to be removed.  If the -perm key is missing, all permissions
     are removed for the given user. If both keys are missing, all permissions
     are removed from all users.

     The -list userperm command is used to list user permissions. The key
     -name defines the user name. If -name key is missing, all users are
     listed. The key -perm defines the permission. If the -perm key is
     missing, all permissions are listed. If both keys are missing all
     permissions are listed for all users.

ESP ARCHIVE MANAGEMENT
SYNOPSIS
     espconfig -list archive [<archive name> ..<archive name>]
     espconfig -drop archive  <archive name>

DESCRIPTION
     The -list archive command is used to list ESP archives. Archives
     specified in the command are listed. If archives name is missing in
     command line, all archives are listed. The list command displays the
     archive name and date information for the archive.

     The -drop archive command is used to drop an existing ESP archive.

ESP CUSTOMER PROFILE CONFIGURATION
SYNOPSIS
     espconfig -create customer_profile
                     -fname   <first name>
                     -lname   <last name>
                     -phone   <phone>
                     -email   <email>
                    [-street1 <street address line1>]
                    [-street2 <street address line2>]
                    [-street3 <street address line3>]
                    [-city    <city>]
                    [-state   <state/province>]
                    [-zip     <postal code>]
                     -country <country>
                    [-site_id <site id>]
     espconfig -update customer_profile
                    [-fname   <first name>]
                    [-lname   <last name>]
                    [-phone   <phone>]
                    [-email   <email>]
                    [-street1 <street address line1>]
                    [-street2 <street address line2>]
                    [-street3 <street address line3>]
                    [-city    <city>]
                    [-state   <state/province>]
                    [-post    <postal code>]
                    [-country <country>]
                    [-site_id <site id>]
     espconfig -show customer_profile

DESCRIPTION
     The -create command is used to create ESP customer profile. The first
     four option are mandatory in this command.

     The -update command is used to update ESP customer profile. First four
     option in this command and cannot be left blank.

     The -show command prints on the console the customer profile information
     as programmed.

     The option for this commands are the following:

     -fname <first name>
             option specifies the first name of the contact at the customer
             site.

     -lname <last name>
             option specifies the last name of the contact at the customer
             site.

     -phone <phone>
             option specifies the phone number for the contact at the customer
             site.

     -email <email>
             option specifies the email address of the contact at the customer
             site.

     -street1 <street address line1>
             option specifies the line1 of the street address of the contact
             at the customer site.

     -street2 <street address line2>
             option specifies the line2 of the street address of the contact
             at the customer site.

     -street3 <street address line3>
             option specifies the line3 of the street address of the contact
             at the customer site.

     -city <city>
             option specifies the city of the contact at the customer site.

     -state <state/province>
             option specifies the state or province of the contact at the
             customer site.

     -post <postal code>
             option specifies zip/postal code of the contact at the customer
             site.

     -country <country>
             option specifies the country of the contact at the customer site.

     -site_id <site id>
             option specifies the site id.

ESP GLOBAL CONFIGURATION
SYNOPSIS
     espconfig -enable call_logging  [-text|-comp_encoded]
                         [-from <sender email address>]
                         [-email1 <email address>]
                         [-email2 <email address>]
     espconfig -enable  {event_registration|
                         event_throttling|
                         event_actions|
                         shutdown_reason}
     espconfig -enable mail -from <email address>
     espconfig -disable {call_logging|
                         event_registration|
                         event_throttling|
                         event_actions|
                    shutdown_reason}
     espconfig -show {event_registration|
                         event_throttling|
                         event_actions|
                         shutdown_reason}
     espconfig -disable mail
     espconfig -show call_logging
     espconfig -show mail

     espconfig -flushdb [-sysid <system id>
                        |-host <host name>]
                        [config|all]
     espconfig -reconstructdb


DESCRIPTION
     The -enable key enables selected feature, while -disable key disables
     selected feature. The features are the following:

     call_logging
             this feature specifies whether or not ESP should send email
             messages to SGI about registered events. (Under specific service
             contracts SGI uses this data to open trouble tickets and respond
             to problems before the problems affect system availability.) When
             call logging is enabled, the optional keys -text and
             -comp_encoded define the email message format.  The -text key
             specifies to send messages in the plain text format, while
             -comp_encoded key specifies to send the messages in compressed,
             encrypted and uuencoded format. Only one of the keys can be
             specified in the command line.  If both keys are missing, then
             plain text format is assumed. Email sent to SGI will appear as
             sent from root account or the specified user specified via the
             key -from. Keys -email1 and -email2 specifies additional email
             addresses to send a message. The format of message in the for
             -email1 is always plain text and format of message for -email2 is
             the same as the setting provided by the option text or
             comp_encoded. Mails that are received using the comp_encoded
             option may be decoded using the utility amreceieve.

     mail    this feature specifies the value of the Mail sender. This is the
             same specification as described in call_logging in regards to the
             key -from.

     event_registration
             this feature specifies whether or not ESP should register events.

     event_throttling
             this feature specifies whether or not ESP should throttle events.

     event_actions
             this feature specifies whether or not ESP should perform actions.

     shutdown_reason
             this feature specifies whether or not user will be prompted to
             enter a reason when they shut down the system.

     The espconfig -flushdb command is used to clear data registered
     concerning the selected system, the current or client in the case of SGM
     site.  If espconfig is running on an SGM, the optional key -sysid defines
     the client by specifying the system id against which the command applies
     to.  The optional -host key is used to specify the client system by host
     name.  Only one of the keys needs to be provided on command line. If both
     of keys are not provided, then the system on which the command is being
     run is affected. The client data is removed from SGM, but the client
     itself is not affected. The keys [config|all] define data that is
     affected by the command. Only one of the keys can be specified at a time.
     If both keys are missing all data except system configuration related
     data is cleared. The key config specifies to clear only configuration
     data. Key all specifies to clear both types of data.

     The espconfig -reconstructdb command reinitialize the ESP data base to
     its initial state. This command should be used with extreme caution as
     all historical data will be lost. The entire ESP database is deleted and
     recreated.


SYSTEM GROUP MANAGER(SGM) CONFIGURATION
SYNOPSIS
     espconfig -update sgmlicense

     espconfig -add sgmclient <client alias> <client hostname>
                              <server alias> [-p <password>]
     espconfig -add sgmserver <server alias> <server hostname>
                              <client alias> [-p <password>]

     espconfig -delete sgmserver <server alias>
     espconfig -delete sgmclient <client alias>

     espconfig -ping sgmserver <server alias>
     espconfig -ping sgmclient <client alias>

     espconfig -update sgmevents <client alias>

     espconfig -subscribe <client alias>
                            [{-f <filename> |
                             [-c <class list>][-e <event list>]}]

     espconfig -unsubscribe <client alias>
                            [{-f <filename> |
                    {-a} |
                             [-c <class list>][-e <event list>]}]

     espconfig -logEnable <client alias>
                            [{-f <filename> |
               {-a} |
                             [-c <class list>][-e <event list>]}]

     espconfig -logDisable <client alias>
                            [{-f <filename> |
                    {-a} |
                             [-c <class list>][-e <event list>]}]

     espconfig -show_subscription sgmclient <client alias> [-r]

DESCRIPTION
     System Group Manager(SGM) enables Embedded Support Partner to collect
     various information about systems in a system group. It allows :

        - Register subscribed events that are detected on the
          other systems in the group
        - Execute actions for those events on a group manager
        - Generate reports for a remote system or group of
          systems
        - Provide hardware and software information for any
          system in the group (System Configuration event
          class must be subscribed)
        - Provide availability information for any system in
          the group or for a group of systems (Availability
          event class must be subscribed)

     All components of SGM are installed on your system as a part of ESP.
     However, a nodelocked license is required to allow ESP function as a
     group manager. Without the license or with an expired license Embedded
     Support Partner cannot function in the group manager mode. All SGM
     related operations (except configuring system as group member for another
     Group manager) will be blocked. Use Key-O-Matic at the SGI Web site
     (www.sgi.com) to obtain a permanent license, or contact the local SGI
     support office for more information about obtaining a permanent license.


     -update sgmlicense command refreshes and displays information about SGM
     license installed on system.  This must be executed installing or de-
     installing SGM license.

     Follow the two steps to configuring System Group Manager for remote event
     monitoring:

      - Establishing communication between the SGM group manager
        and the SGM group member.
      - Subscribe events from the SGM client.

     The system can be configured as an SGM server and/or a client to an
     already functioning SGM server.

     In order to group manager to be able to communicate with group member,
     appropriate setup must be done both on group member and group manager
     sides. On the SGM Client (group member), register(declare) a selected
     host as a SGM server (group manager) for this client. The SGM Client
     allows communication only for registered SGM Servers. On the SGM Server
     (group manager), register(declare) the selected host(s) as it's SGM
     Client (group member). The SGM Server can communicate only with
     registered SGM Client. The registration of the SGM client or the SGM
     server can be done in any order.

     espconfig -add sgmclient <client alias> <client hostname>
                              <server alias> [-p <password>]
     espconfig -add sgmserver <server alias> <server hostname>
                              <client alias> [-p <password>]

     The -add sgmclient command register new SGM client (group member) on
     group manager.

     <client alias>
          A name by which the group member is known to group manager. This
          parameter can contain any non-blank space characters, except single
          or double quotes. This entry must be identical to the one that is
          specified on the group member side as the <client alias> while
          registering group manager.

     <client hostname>
          A full name or an alias of the system that is set up as a group
          member. This hostname must be known to group manager system. It will
          be expanded to a fully qualified hostname during the registration
          process.

     <server alias>
          The name by which the server is known to the client. This name must
          be provided on the client side as the <server alias> parameter.

     [-p <password>]
          A password that the client and server use for mutual client-server
          authentication. Therefore, the same password must be entered on the
          client side for this system. The password must contain at least 8
          characters. This password is maintained on a client-server pair
          basis. If this parameter is omitted you will be prompted to enter a
          password.

     The -add sgmserver command register new SGM server (group manager) on
     group member.

     <server alias>
          A name by which the SGM server is known to a client. This parameter
          can contain any non-blank space character, except single or double
          quotes. This entry should be identical to the one specified on the
          server side as a <server alias> while registering group member.

     <server hostname>
          A full name or an alias of the system that is set up as group
          manager and of which this system will be a client. This hostname
          must be known to this system. It will be expanded to a fully
          qualified hostname during the registration process.

     <client alias>
          The name by which the client is known to the server. This name must
          be provided on the server side as the <client alias>.

     [-p <password>]
          A password that the client and server use for mutual client-server
          authentication. Therefore, the same password must be entered on the
          client side for this system. The password must contain at least 8
          characters. This password is maintained on a client-server pair
          basis. If this parameter is omitted you will be prompted to enter a
          password.

     Important:  It is strongly recommended that you do not create duplicate
     hosts on a client or on a server side.  It is strongly recommended that
     you do not create cycles. For example, system B monitors system A, and
     system A monitors system B. However, the following setup is acceptable.
     System A monitors systems B and D, and system C monitors systems A and D.

     espconfig -show sgmclients
     espconfig -show sgmservers

     -show sgmclients(sgmservers) command displays the list of SGM clients
     (servers) currently registered on the system as well as client(server)
     hostname, server(client) alias and communication protocol that the
     client/server will use to communicate with its peer (currently RPC).

     espconfig -delete sgmserver <server alias>
     espconfig -delete sgmclient <client alias>

     -delete sgmserver <server alias>
     -delete sgmclient <client alias>
         commands unregister specified SGM client(server)

     <server alias>
          SGM server to be unregistered.

     <client alias>
          SGM client to be unregistered.

     Note: Though the de-registration process severe the communication link
     between client and server no data associated with client will be
     physically deleted. As a result, the system can be re-registered again to
     restore functionality. Use -flashdb command to remove data associated to
     a particular client on the group manager. If a client is de-registered on
     the SGM server side, it is also recommended de-register the server on the
     client side.
     espconfig -ping sgmserver <server alias>
     espconfig -ping sgmclient <client alias>

     The -ping sgmserver(client) command should be used to test the
     "connection" to the SGM server(client) given by the <server
     alias>(<client alias>) parameter.

EVENT SUBSCRIPTION
     To register events that are detected on other system in the group and to
     be able to react somehow on these events (take action) on group manager,
     subscribe for these events from that system.

     When Embedded Support Partner on the group member system registers
     subscribes events, it logs them in its database, performs any actions
     assigned to the events, and then forwards the events to Embedded Support
     Partner on the group manager system. Then, the Embedded Support Partner
     on the group manager system registers the events, logs the events in its
     database, and performs any actions assigned to the events. This process
     creates a central repository of data on the group manager system, which
     enables access to information about all of the systems in the group from
     a single interface.

     Though events can be subscribed that are recognized on group member
     system, only events that are allowed to be registered on system can be
     forwarded to group manager. So global disabling of event registration on
     the group member disables event forwarding for all events from this host.

     Event forwarding is an internal ESP action, so one must keep ESP actions
     enabled in order to be able to forward events to group manager.

     Event forwarding is unaffected by event throttle settings for particular
     event on group member.  Subscribed events will be delivered to group
     manager, and then will be throttled using settings stored on group
     manager. On the group manager event settings are stored on a per host
     basis.  Disabling event registration on group manager whether it is
     global or for particular event is not propagated to group members.
     Disabled events that are propagated from the group members are dropped.

     The following sets of commands is used to perform event subscription

     espconfig -show   sgmevents <client alias>
     espconfig -update sgmevents <client alias>
     espconfig -subscribe <client alias>
                            [{-f <filename> |
                             [-c <class list>][-e <event list>]}]
     espconfig -unsubscribe <client alias>
                            [{-a|-f <filename>|
                             [-c <class list>][-e <event list>]}]
     espconfig -show_subscription sgmclient <client alias> [-r]

     The -show sgmevents command displays the list of all events that group
     manager is currently capable of registering from the SGM client specified
     by <client alias> parameter as well as current subscription status for
     each event. This list is maintained on per client basis and stored in
     group managers local database. Only events from this list can be
     potentially subscribed and registered by group manager. Use -update
     sgmevents to update this list.

     The -update sgmevents <client alias> command updates the list of events
     that the group manager capable to receive from SGM client specified by
     <client alias> parameter. Upon execution, the group manager retrieves the
     list of events that the client is capable of generating and merges it
     with the one that is stored on group manager.

     Note: If you register SGM client on group manager for the first time
     there are no events in the list stored on group manager. Execute -update
     sgmevents command at least once to retrieve the list of events.


     The -subscribe command should be used from group manager system to
     subscribe for selected events and/or event classes.

     <client alias>
          parameter specifies the client to subscribe events for.

     -c <class list>
          space separated list of classes to be subscribed. ESP uses integer
          numbers to identify event classes (class_id). Use -show sgmevents
          command to retrieve the list of class_id's for all events.

     -e <event list>
          space separated list of events to be subscribed. ESP uses integer
          numbers called type_id to identify particular events. Use -show
          sgmevents command to retrieve the list of all type_id's that are
          available for particular client.

     -f <filename>
          specifies file containing list of events and/or classes in the same
          format as it can be used in command line.

     The -unsubscribe command remove subscription for SGM client specified by
     <client alias> parameter.

     -c <class list>
          space separated list of classes to be unsubscribed.

     -e <event list>
          space separated list of events to be unsubscribed.

     -f <filename>
          specifies file containing list of events and/or classes in the same
          format as it can be used in command line.
     -a - Unsubscribe "all"

     -show_subscription sgmclient command displays list of events currently
     subscribed for SGM client specified by <client alias> parameter. This
     list comes from group manager database. With the -r option given, the
     command retrieve the list from ESP database located on remote system.  In
     most cases, for correctly configured system, both lists will be
     identical.

     Note: Some legitimate operations (eg. enabling/disabling events,
     loading/removing event profiles, adding/deleting events) performed can
     severely affect subscription mechanism. It may be required to re-
     subscribe for all or selected events after performing such operations.


PERFORMANCE CONFIGURATION
SYNOPSIS
     espconfig -on performance
     espconfig -off performance
     espconfig -list performance [-status|-enable|-disable]
     espconfig -enable performance  -pd {all|<pmie rule description>}
     espconfig -disable performance -pd {all|<pmie rule description}>

DESCRIPTION
     The espconfig -on performance and espconfig -off performance will
     respectively stop and start pmie. Be aware this affect pmie startup
     outside ESP scope as well. This command actually chkconfig pmie on or off
     and stop or start pmie.

     The espconfig -list performance list if pmie is on or off ( -status ) and
     rules. Keys like -enable or -disable can be used to control rules
     selection. Default is all rules.

     The espconfig -enable performance and espconfig -disable performance
     allows 'all' or a list of pmie rules to be enabled or disabled. Changes
     are effective immediately.

SYSTEM MONITORING CONFIGURATION
SYNOPSIS
     espconfig monitor -list    [ <service list> ]
     espconfig monitor -show    [ <service list> ] [-sgmclient <host list>]
     espconfig monitor -enable  [ <service list> ] [-sgmclient [all|<host list>] ]
     espconfig monitor -disable [ <service list> ] [-sgmclient [all|<host list>] ]

     The espconfig monitor -list list all or selected service ESP can monitor.
     Output include service name abbreviation and a a description. The word
     HOST in the description is actually substituted upon execution for each
     sgmclient host associated to that service.

     The espconfig monitor -show list all Services associated to all or
     selected host.

     The espconfig monitor -enable and espconfig monitor -disable alows
     selected Service to be enabled or disabled on all or selected host.


SEE ALSO
     espreport(1)